
library(lmerTest)
library(boot)
library(plyr)
library(tidyverse)
library(MCMCglmm)
library(brms)
library(bayestestR)
library(sjPlot)
library(chron)
library(margins)
library(utils)
library(car)
library(ape)

################################################################################
### Create Functions: ##########################################################
################################################################################

# Calculate overlap in posterior distributions
ropeANOVA=function(x){
  hdi=hdi(x) %>% as.data.frame()
  rope=matrix(nrow=nrow(hdi), ncol=nrow(hdi))
  for(i in 1:nrow(hdi)){
    rope[,i]=as.data.frame(rope(x, ci=0.95, ci_method="HDI", range=c(hdi$CI_low[i], hdi$CI_high[i])))$ROPE_Percentage
  }
  rownames(rope) = c("House Finch", "Woodcock", "Raven", "Jay")
  colnames(rope) = c("House Finch", "Woodcock", "Raven", "Jay")
  return(rope)
}

################################################################################
### Load and prep data: ########################################################
################################################################################

data = read.csv("Mouton_etal_ISSJPreyNaivete_BehavioralData.csv")
data$Respond = as.factor(data$Respond)
data$Species = as.factor(data$Species)
data$Time = times(data$Time)
data$Year = year(dates(data$Date))
data$Treatment = as.factor(data$Treatment)

################################################################################
### Probability of Response: ###################################################
################################################################################

### Sample sizes by Species and Island: ########################################
# Santa Rosa
length(unique(subset(data, Island=="Santa Rosa")$Trial))
subset(data, Island=="Santa Rosa") %>% group_by(Species) %>% summarize(n_Trials= length(unique(Trial))) %>% as.data.frame()
summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY")$Species)
summary(subset(data, Island=="Santa Rosa" & Treatment=="RAVEN")$Species)
summary(subset(data, Island=="Santa Rosa" & Treatment=="WOODCOCK")$Species)
summary(subset(data, Island=="Santa Rosa" & Treatment=="HOUSE FINCH")$Species)


# Santa Cruz
length(unique(subset(data, Island=="Santa Cruz")$Trial))
subset(data, Island=="Santa Cruz") %>% group_by(Species) %>% summarize(n_Trials= length(unique(Trial))) %>% as.data.frame()
summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY")$Species)
summary(subset(data, Island=="Santa Cruz" & Treatment=="HOUSE FINCH")$Species)

nSR_20=levels(subset(data, Island=="Santa Rosa" &Treatment=="JAY")$Species)[which(summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY")$Species)>20)]
nSC_20=levels(subset(data, Island=="Santa  CRUZ" &Treatment=="JAY")$Species)[which(summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY")$Species)>20)]
nSC_20 = c(nSC_20, "ALHU") # ALHU samaple size is <20 on Santa Cruz, but is included in some cases below.

nSR_not20=levels(subset(data, Island=="Santa Rosa" &Treatment=="JAY")$Species)[which(summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY")$Species)%in%1:19)]
nSC_not20=levels(subset(data, Island=="Santa  CRUZ" &Treatment=="JAY")$Species)[which(summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY")$Species)%in%1:19)]


### Reshape data for probability of response figures ###########################

# Santa Rosa
ndataSR=data.frame(Species=names(summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY")$Species)),
                   Jay=summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY")$Species),
                   Raven=summary(subset(data, Island=="Santa Rosa" & Treatment=="RAVEN")$Species),
                   Woodcock=summary(subset(data, Island=="Santa Rosa" & Treatment=="WOODCOCK")$Species),
                   HouseFinch=summary(subset(data, Island=="Santa Rosa" & Treatment=="HOUSE FINCH")$Species))
ndataSR = subset(ndataSR, Species%in%nSR_20)
ndataSR = pivot_longer(ndataSR, Jay:HouseFinch, names_to="Treatment", values_to="n")
ndataSR$Treatment=factor(ndataSR$Treatment, levels=c("House Finch", "Jay", "Woodcock", "Raven"))
ndataSR=arrange(ndataSR, Treatment)

dfSR <- subset(data, Island=="Santa Rosa" & Species %in% nSR_20) %>%
  group_by(Island, Species, Respond) %>%
  summarise(Jay = sum( Treatment=="JAY") ,
            Woodcock = sum( Treatment=="WOODCOCK") ,
            Raven = sum( Treatment=="RAVEN"),
            HouseFinch = sum( Treatment=="HOUSE FINCH")) %>%
  gather(key = Group,value = Val, Jay:HouseFinch) %>% as.data.frame()

ndataSR$n2 = ifelse(ndataSR$n<10, NA, ndataSR$n)

dfSR$percVal= dfSR$Val/rep(ndataSR$n2, each=2)
dfSR$Group=factor(dfSR$Group, levels=c("HouseFinch", "Woodcock", "Raven", "Jay"))

# Santa Cruz
ndataSC=data.frame(Species=names(summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY")$Species)),
                   Jay=summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY")$Species),
                   Raven=summary(subset(data, Island=="Santa Cruz" & Treatment=="RAVEN")$Species),
                   Woodcock=summary(subset(data, Island=="Santa Cruz" & Treatment=="WOODCOCK")$Species),
                   HouseFinch=summary(subset(data, Island=="Santa Cruz" & Treatment=="HOUSE FINCH")$Species))
ndataSC = subset(ndataSC, Species%in%nSC_20)
ndataSC = pivot_longer(ndataSC, Jay:HouseFinch, names_to="Treatment", values_to="n")
ndataSC$Treatment=factor(ndataSC$Treatment, levels=c("HouseFinch", "Jay", "Woodcock", "Raven"))
ndataSC=arrange(ndataSC, Treatment)

dfSC <- subset(data, Island=="Santa Cruz" & Species%in%nSC_20) %>% droplevels() %>%
  group_by(Island, Species, Respond) %>%
  summarise(Jay = sum( Treatment=="JAY") ,
            Woodcock = sum( Treatment=="WOODCOCK") ,
            Raven = sum( Treatment=="RAVEN"),
            HouseFinch = sum( Treatment=="HOUSE FINCH")) %>%
  gather(key = Group,value = Val, Jay:HouseFinch) %>% as.data.frame()

# Add missing rows for species with no "YES" responses (i.e. PSFL)
dfSC = add_row(dfSC, Island="Santa Cruz", Species="PSFL", Respond="YES", Group="Jay", Val=0, .after=21)
dfSC = add_row(dfSC, Island="Santa Cruz", Species="PSFL", Respond="YES", Group="Woodcock", Val=0, .after=46+1)
dfSC = add_row(dfSC, Island="Santa Cruz", Species="PSFL", Respond="YES", Group="Raven", Val=0, .after=71+2)
dfSC = add_row(dfSC, Island="Santa Cruz", Species="PSFL", Respond="YES", Group="HouseFinch", Val=0, .after=96+3)

ndataSC$n2 = ifelse(ndataSC$n<10, NA, ndataSC$n)
dfSC$percVal= dfSC$Val/rep(ndataSC$n2, each=2)
dfSC$Group=factor(dfSC$Group, levels=c("HouseFinch", "Woodcock", "Raven", "Jay"))


### Santa Cruz Plots: ##########################################################

dfBoth=bind_rows(dfSC, dfSR) %>% filter(Species%in%nSC_20 & Species!="ISSJ"& Species!="ATFL" & Group%in%c("Jay"))

dfBoth2=subset(dfBoth, Group%in%c("HouseFinch", "Jay") & Respond=="YES" ) %>% select(!Val) %>% pivot_wider( names_from=Island, values_from=percVal)
dfBoth2 = dfBoth2 %>% plyr::rename(replace=c('Santa Cruz'= "Cruz" , 'Santa Rosa'= "Rosa"))
dfBoth2 = subset(dfBoth2, Species!="ALHU")

(Fig_3b = ggplot(dfBoth2,
       aes(x=Cruz, y=Rosa))+
  geom_point()+
  geom_text(aes(label=Species), nudge_x=0, nudge_y=0.01) +
  theme_classic() +
  scale_fill_manual(values=c("steelblue2",  "steelblue"))+
  labs(y="Percent Responding to Jay on Santa Rosa", x="Percent Responding to Jay on Santa Cruz") )
# ggsave("Fig_3b.pdf", 
#        plot=Fig_3b, width=15, height=13, dpi=300, units="cm")

# Test correlation between Islands
cor.test(dfBoth2$Rosa, dfBoth2$Cruz)

### Probability of response Models: ###########################################

### All species together:
data$Treatment=factor(data$Treatment, levels=c("HOUSE FINCH", "WOODCOCK", "RAVEN", "JAY"))
data$Respond01=ifelse(data$Respond=="YES", 1, 0)
prALL=brm(Respond01~Treatment + (1|Trial) + (1|Species) , 
          family=bernoulli(), data=subset(data, Island=="Santa Rosa" & Species%in%nSR_20))
summary(prALL)
pp_check(prALL, type="stat_freqpoly", ndraws=NULL) 
ropeANOVA(prALL)
# save(prALL, file="prALL.R")
# load("prALL.R")


prALLdata=bind_cols(conditional_effects(prALL, prob=0.95)$Treatment, conditional_effects(prALL, prob=0.75)$Treatment[,9:10], conditional_effects(prALL, prob=0.50)$Treatment[,9:10])
names(prALLdata)[9:14] = c("lower95", "upper95",  "lower75","upper75",  "lower50", "upper50")
prALLdata$Treatment = factor(c("House Finch", "Woodcock", "Raven", "Jay"), levels=c("House Finch", "Woodcock", "Raven", "Jay"))
(Fig_1b = ggplot(prALLdata, aes(x=Treatment, y=estimate__, color=Treatment)) +
  geom_errorbar(aes(ymin=lower95, ymax=upper95), width=0) +
  geom_errorbar(aes(ymin=lower75, ymax=upper75), linewidth=1.5, width=0) +
  geom_errorbar(aes(ymin=lower50, ymax=upper50), linewidth=3, width=0) +
  geom_point(size=5)+
  theme_classic() +
  scale_color_manual(values=c("#009E73", "orange", "darkgray", "steelblue"))+
  labs(y="Probability of Responding") )
# ggsave("Fig_1b.pdf", 
#        plot=Fig_1b, width=15, height=13, dpi=300, units="cm")

### Each Species separately:
prSPPsr=prSPPppc = list()
for(spp in nSR_20){
  prSPP=brm(Respond01~Treatment + (1|Trial), 
            family=bernoulli(), data=subset(data, Island=="Santa Rosa" & Species==spp))
  
  prSPPdata=bind_cols(conditional_effects(prSPP, prob=0.95)$Treatment, conditional_effects(prSPP, prob=0.75)$Treatment[,8:9], conditional_effects(prSPP, prob=0.50)$Treatment[,8:9])
  prSPPdata$Species = spp
  chains = extract_draws(prSPP)$dpars$mu$fe$b
  names(prSPPdata)[8:13] = c("lower95", "upper95",  "lower75","upper75",  "lower50", "upper50")
  prSPPppc[[spp]] = pp_check(prSPP, type="stat_freqpoly", ndraws=NULL)
  prSPPsr[[spp]] = list(summary=summary(prSPP), data=prSPPdata, chains=chains)
} #spp
# save(prSPPsr, file="prSPPsr.R")
# load("prSPPsr.R")

# Visualize Posterior predictive check for each species
for(spp in nSR_20){
  print(spp)
  prSPPppc[[spp]] %>% print()
  readline(prompt="Press [enter] to continue")
}  

# Model output for each species
for(spp in nSR_20){
  print(spp)
  p.chains = data.frame(HouseFinch = inv.logit(prSPPsr[[spp]]$chains[,1])*100,
                        Woodcock = inv.logit(prSPPsr[[spp]]$chains[,1] +prSPPsr[[spp]]$chains[,2])*100,
                        Raven = inv.logit(prSPPsr[[spp]]$chains[,1] +prSPPsr[[spp]]$chains[,3])*100,
                        Jay = inv.logit(prSPPsr[[spp]]$chains[,1] +prSPPsr[[spp]]$chains[,4])*100)     

  print(describe_posterior(p.chains, ci_method="hdi", test="none") %>% as.data.frame() )
  readline(prompt="Press [enter] to continue")
} #spp


prSPPdata=prSPPsr[[1]]$data
for(spp in nSR_20[2:length(nSR_20)]){
  prSPPdata=bind_rows(prSPPdata, prSPPsr[[spp]]$data)
}
names(prSPPdata)[6]="Estimate"
prSPPdata$Treatment = ifelse(prSPPdata$Treatment=="HOUSE FINCH", "House Finch", 
                             ifelse(prSPPdata$Treatment=="WOODCOCK", "Woodcock",
                                                                             ifelse(prSPPdata$Treatment=="RAVEN", "Raven", "Jay")))
prSPPdata$Treatment = factor(prSPPdata$Treatment, levels=c("House Finch", "Woodcock", "Raven", "Jay"))

(Fig_1a = ggplot(subset(prSPPdata, Species!="HOFI" & Treatment%in%c("House Finch", "Jay")), 
            aes(x=Treatment, y=Estimate, color=Species, linetype=Species, shape=Species, group=Species)) +
  geom_point(size=5) +
  geom_line() +
  theme_classic()+
  labs(y="Probability of Responding") )
ggsave("Fig_1a.pdf", 
       plot=Fig_1a, width=15, height=13, dpi=300, units="cm")



### Santa Cruz
prCRUZ=brm(Respond01~Treatment + (1|Trial) + (1|Species) , 
           family=bernoulli(),subset(data, Island=="Santa Cruz" & Treatment%in%c("HOUSE FINCH", "JAY") & 
                                       Species%in%nSC_20 & Species!="ISSJ"))
summary(prCRUZ)
pp_check(prCRUZ, type="stat_freqpoly", ndraws=NULL) 
# save(prCRUZ, file="prCRUZ.R")
# load("prCRUZ.R")

prBOTH=brm(Respond01~Island*Treatment + (1|Trial) + (1|Species) , 
           family=bernoulli(),subset(data, Treatment%in%c("HOUSE FINCH", "JAY") & 
                                       Species%in%nSC_20 & Species!="ISSJ"))
summary(prBOTH)
pp_check(prBOTH, type="stat_freqpoly", ndraws=NULL) 
# save(prBOTH, file="prBOTH.R")
# load("prBOTH.R")

prBOTHdata=bind_cols(conditional_effects(prBOTH, prob=0.95)$'Island:Treatment', conditional_effects(prBOTH, prob=0.75)$'Island:Treatment'[,11:12], conditional_effects(prBOTH, prob=0.50)$'Island:Treatment'[,11:12])
names(prBOTHdata)[11:16] = c("lower95", "upper95",  "lower75","upper75",  "lower50", "upper50")
prBOTHdata$TrtIsland = paste0(prBOTHdata$Treatment, prBOTHdata$Island)

prBOTHdata$Treatment = factor(c("House Finch", "Jay","House Finch", "Jay"), levels=c("House Finch", "Jay"))

(Fig_3a = ggplot(prBOTHdata, aes(x=Treatment, y=estimate__, shape=Island,  color=TrtIsland)) +
  # geom_line(aes(group=Island), position=position_dodge(0.2)) +
  geom_errorbar(aes(ymin=lower95, ymax=upper95), width=0, position=position_dodge(width=0.2)) +
  geom_errorbar(aes(ymin=lower75, ymax=upper75), size=1, width=0, position=position_dodge(width=0.2)) +
  geom_errorbar(aes(ymin=lower50, ymax=upper50),size=3, width=0, position=position_dodge(width=0.2)) +
  geom_point(size=5, position=position_dodge(width=0.2)) +
  theme_classic() +
  scale_color_manual(values=c("#009E73", "#084706", "steelblue", "#063768"))+
  # scale_linetype_manual(values=c("solid", "dashed", "solid", "dashed"))+
  scale_shape_manual(values=c(15, 16)) +
  # scale_fill_manual(values=c("purple2", "darkgray"))+
  labs(y="Probability of Responding", fill="") +
    theme(legend.position = "none"))

# ggsave("Fig_3a.pdf", 
#        plot=Fig_3a, width=10, height=13, dpi=300, units="cm")


################################################################################
### Intensity of Response: #####################################################
################################################################################

### Sample sizes by Species and Island: ########################################
# Santa Rosa
summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY" & Respond=="YES")$Species)
summary(subset(data,  Island=="Santa Rosa" &Treatment=="WOODCOCK" & Respond=="YES")$Species)
summary(subset(data,  Island=="Santa Rosa" & Treatment =="RAVEN" & Respond=="YES")$Species)

# Santa Cruz
summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY" & Respond=="YES")$Species)
summary(subset(data,  Island=="Santa Cruz" &Treatment=="WOODCOCK" & Respond=="YES")$Species)
summary(subset(data,  Island=="Santa Cruz" & Treatment =="RAVEN" & Respond=="YES")$Species)


nSRint_5=levels(subset(data, Island=="Santa Rosa" &Treatment=="JAY"& Respond=="YES")$Species)[which(summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY"& Respond=="YES")$Species)>=5)]
nSCint_5=levels(subset(data, Island=="Santa  Cruz" &Treatment=="JAY"& Respond=="YES")$Species)[which(summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY"& Respond=="YES")$Species)>=5)]

nSRint_not5=levels(subset(data, Island=="Santa Rosa" &Treatment=="JAY"& Respond=="YES")$Species)[which(summary(subset(data, Island=="Santa Rosa" & Treatment=="JAY"& Respond=="YES")$Species)%in%1:4)]
nSCint_not5=levels(subset(data, Island=="Santa Cruz" &Treatment=="JAY"& Respond=="YES")$Species)[which(summary(subset(data, Island=="Santa Cruz" & Treatment=="JAY"& Respond=="YES")$Species)%in%1:4)]


### Plots of Intensity of Response #############################################

data2=data %>% filter(Treatment!="HOUSE FINCH" ) %>% pivot_longer(cols=starts_with("Score"), values_to="Score") %>% as.data.frame()
data2$Treatment=factor(data2$Treatment, levels=c( "WOODCOCK", "RAVEN", "JAY")) 

# Santa Rosa
dataSR=subset(data2, Island=="Santa Rosa" & Species%in%nSRint_5) %>% as.data.frame()
(Fig_2 = ggplot(dataSR, aes(x=Species, y=Score, color=Treatment, fill=Treatment)) +
  geom_boxplot(position=position_dodge(preserve="single")) +
  scale_y_continuous(breaks=seq(0, 7.1, by=1), limits=c(0, 7)) +
  scale_fill_manual(values=c("orange", "lightgray", "steelblue"))+
  scale_color_manual(values=c("orange3", "darkgray", "darkblue"))+
  theme_classic() )
ggsave("Fig_2.pdf", 
       plot=Fig_2, width=20, height=10, dpi=300, units="cm")


dataSR=subset(data2, Island=="Santa Rosa" & Species%in%nSRint_not5) %>% as.data.frame()
(Fig_S1a = ggplot(dataSR, aes(x=Species, y=Score, color=Treatment, fill=Treatment)) +
    geom_boxplot(position=position_dodge(preserve="single")) +
    scale_y_continuous(breaks=seq(0, 7.1, by=1), limits=c(0, 7)) +
    scale_fill_manual(values=c("orange", "lightgray", "steelblue"))+
    scale_color_manual(values=c("orange3", "darkgray", "darkblue"))+
    theme_classic() )
# ggsave("Fig_S1a.pdf", 
#        plot=Fig_S1a, width=15, height=10, dpi=300, units="cm")


# Santa Rosa vs. Santa Cruz
dataBoth=subset(data2, Treatment=="JAY" & Species%in%nSCint_5 & Species!="ISSJ")
(Fig_4 = ggplot(dataBoth, aes(x=Species, y=Score, color=Island, fill=Island)) +
  geom_boxplot(position=position_dodge(preserve="single")) +
  scale_y_continuous(breaks=seq(0, 7.1, by=1), limits=c(0, 7)) +
  scale_fill_manual(values=c("steelblue2", "steelblue"))+
    scale_color_manual(values=c("steelblue4", "darkblue"))+
  theme_classic()  )
# ggsave("Fig_4.pdf", 
#        plot=Fig_4, width=20, height=10, dpi=300, units="cm")

dataBoth=subset(data2, Treatment=="JAY" & Species%in%nSCint_not5 & !(Species%in%c("ISSJ", "ATFL")))
(Fig_S1b = ggplot(dataBoth, aes(x=Species, y=Score, color=Island, fill=Island)) +
    geom_boxplot(position=position_dodge(preserve="single")) +
    scale_y_continuous(breaks=seq(0, 7.1, by=1), limits=c(0, 7)) +
    scale_fill_manual(values=c("steelblue2", "steelblue"))+
    scale_color_manual(values=c("black", "black"))+
    theme_classic()  )
# ggsave("Fig_S1b.pdf", 
#        plot=Fig_S1b, width=10, height=10, dpi=300, units="cm")


### Intensity of Response Models ###############################################

### Santa Rosa Only:

# All species together:
intALL=brm(Score~Treatment + (1|Trial) + (1|Species) , 
           family=cumulative(),  data=dataSR)
summary(intALL)
pp_check(intALL, type="stat_freqpoly", ndraws=NULL) 
# save(intALL, file="intALL.R")
# load("intALL.R")

# Each species individually:
intSPPsr=list()
for(spp in nSRint_5){
  intSPP=brm(Score~Treatment + (1|Trial), family=cumulative(), data=subset(dataSR, Species==spp))
  intSPPdata=summary(intSPP)$fixed
  intSPPdata$Species = spp
  names(intSPPdata)[3:4] = c("lower95", "upper95")
  chains = extract_draws(intSPP)$dpars$mu$fe$b
  intSPPsr[[spp]] = list(summary=summary(intSPP), data=intSPPdata, chains=chains)
}
# save(intSPPsr, file="intSPPsr.R")
# load("intSPPsr.R")

intSPPdata=intSPPsr[[1]]$data
for(spp in nSRint_5[2:length(nSRint_5)]){
  intSPPdata=bind_rows(intSPPdata, intSPPsr[[spp]]$data)
}
intSPPdata=subset(intSPPdata, grepl("Treatment", rownames(intSPPdata)))
intSPPdata$Treatment = ifelse(grepl("RAVEN", rownames(intSPPdata)), "RAVEN", "JAY" )
rownames(intSPPdata)=NULL
intSPPdata$Estimate = ifelse(intSPPdata$Rhat>1.1, NA, intSPPdata$Estimate)
intSPPdata$upper95 = ifelse(intSPPdata$Rhat>1.1, NA, intSPPdata$upper95)
intSPPdata$lower95 = ifelse(intSPPdata$Rhat>1.1, NA, intSPPdata$lower95)
intSPPdata$Treatment = factor(intSPPdata$Treatment, levels=c("RAVEN", "JAY"))


### Including Santa Cruz:

#All species together:
intCRUZ=brm(Score~Island + (1|Trial) + (1|Species) + (1|Observer), 
            family=cumulative(), data=dataBoth)
summary(intCRUZ)
pp_check(intCRUZ, type="stat_freqpoly", ndraws=NULL) 
# save(intCRUZ, file="intCRUZ.R")
# load("intCRUZ.R")

# Each species individually:
intSPPsc=list()
for(spp in nSCint_5[-c(4, 6)]){
  intCRUZspp=brm(Score~Island + (1|Trial), family=cumulative(), data=subset(dataBoth, Species==spp))
  intCRUZdata=summary(intCRUZspp)$fixed
  intCRUZdata$Species = spp
  names(intCRUZdata)[3:4] = c("lower95", "upper95")
  intSPPsc[[spp]] = list(summary=summary(intCRUZspp), data=intCRUZdata)
}
# save(intSPPsc, file="intSPPsc.R")
# load("intSPPsc.R")

################################################################################
### Comparative Analysis #######################################################
################################################################################

library(ape)
# library(phylolm)
# library(sensiPhy)

### Prep experimental and life history data: ###################################

### Load Life History Data:
lh = read.csv("Mouton_etal_ISSJPreyNaivete_LifeHistoryData.csv")

### Load Phylogenetic Trees: 
trees = read.nexus("Mouton_etal_ISSJPreyNaivete_Trees.nex")
trees[[1]]$tip.label
lh$Latin = c("Selasphorus_sasin", "Calypte_anna",  
      "Thryomanes_bewickii", "Spizella_passerina","Carpodacus_mexicanus", "Vireo_huttoni",
      "Carduelis_psaltria", "Vermivora_celata", "Empidonax_difficilis", 
      "Melospiza_melodia", "Pipilo_maculatus")
rownames(lh) = lh$Latin

### Number of MCMC draws:
ndraws=dim(prSPPsr[[1]]$chains)[1]


####### Calculate probability of response for each species and MCMC draw: ############################

cHouseFinch = lapply(prSPPsr, function(x){
  inv.logit(x$chains[,1])
})

cHouseFinch_post = lapply(cHouseFinch, describe_posterior, centrality=c("mean", "median", "MAP"), ci=0.75, ci_method="hdi") %>% ldply()
names(cHouseFinch_post)[1] = "Species"
cHouseFinch_post = left_join(cHouseFinch_post, lh, by="Species")

cHouseFinch_post[5,3:5] =NA 

# Correct for responses to control:
cWoodcock = lapply(prSPPsr, function(x){
  inv.logit(x$chains[,1] + x$chains[,2])
})

cWoodcock_post = lapply(cWoodcock, describe_posterior, centrality=c("mean", "median", "MAP"), ci=0.5) %>% ldply()
names(cWoodcock_post)[1] = "Species"
cWoodcock_post = left_join(cWoodcock_post, lh, by="Species")

# Correct for responses to control:
cRaven = lapply(prSPPsr, function(x){
  inv.logit(x$chains[,1] + x$chains[,3])
})

cRaven_post = lapply(cRaven, describe_posterior, centrality=c("mean", "median", "MAP"), ci=0.5) %>% ldply()
names(cRaven_post)[1] = "Species"
cRaven_post[6,2:ncol(cRaven_post)]=NA
cRaven_post = left_join(cRaven_post, lh, by="Species")

# Correct for responses to control:
cJay = lapply(prSPPsr, function(x){
  inv.logit(x$chains[,1] + x$chains[,4])
})

cJay_post = lapply(cJay, describe_posterior, centrality=c("mean", "median", "MAP"), ci=0.5) %>% ldply()
names(cJay_post)[1] = "Species"
cJay_post = left_join(cJay_post, lh, by="Species")

#### Plot All Treatments together: ##################################
cJay_post$Treatment = "Jay"
cRaven_post$Treatment = "Raven"
cWoodcock_post$Treatment = "Woodcock"
cHouseFinch_post$Treatment = "HouseFinch"
allTrt_post = bind_rows(cJay_post, cRaven_post, cWoodcock_post, cHouseFinch_post)
allTrt_post$Treatment = factor(allTrt_post$Treatment, levels=c("HouseFinch", "Woodcock", "Raven", "Jay"))
(Fig_5 = ggplot(allTrt_post, aes(x=Ann_Fec, y=logit(Median), linetype=Treatment,  shape=Treatment, color=Treatment)) +
    geom_smooth(method="glm", formula=y ~ poly(x, 1), se=F) +
    geom_point(size=5, position="jitter", alpha=1)+
    theme_classic() +
    theme(axis.title = element_text(size=16)) +
    scale_color_manual(values=c("#009E73", "orange", "darkgray", "steelblue"))+
    scale_shape_manual(values=c("circle", "square", "triangle", "diamond"))+
    labs(y="Logit Probability of Responding", x="Annual Fecundity")  )
ggsave("Fig_5.pdf", 
       plot=Fig_5, width=15, height=13, dpi=300, units="cm")


####### Comparative Analyses including uncertainty: ############################

mod.coefs = array(dim=c(ndraws, 14,7))
treeid = rep(1:ntrees, ndraws/ntrees)
errors = numeric()
dim(mod.coefs)
# mod.coefs[3780,,]

for(i in 1:ndraws){
  tryCatch({
    # Prep data and phylogeny:
    cJay.i = lapply(cJay, function(x){
      x[i]
    }) %>% as.numeric()
    cRaven.i = lapply(cRaven, function(x){
      x[i]
    }) %>% as.numeric()
    cWoodcock.i = lapply(cWoodcock, function(x){
      x[i]
    }) %>% as.numeric()
    cHouseFinch.i = lapply(cHouseFinch, function(x){
      x[i]
    }) %>% as.numeric()
    
    data.i = data.frame(Species = rep(names(prSPPsr), 4), 
                        Response=c(cJay.i, cRaven.i, cWoodcock.i, cHouseFinch.i), 
                        Treatment=rep(c("Jay", "Raven", "Woodcock", "HouseFinch"), each=11))
    data.i = left_join(data.i, lh, by="Species")
    data.i$Response = ifelse(data.i$Species=="HOFI" & data.i$Treatment =="HouseFinch", NA, data.i$Response)
    
    A = ape::vcv.phylo(trees[[treeid[i]]])
    
    # Run model:
    mod = brm(logit(Response)~Treatment*Ann_Fec + Mass +(1|gr(Latin, cov = A)) + (1|Species),
              data = data.i,
              family="gaussian",
              data2 = list(A=A),
              prior = c(
                prior(normal(0, 10), "b"),
                prior(normal(0, 50), "Intercept"),
                prior(student_t(3, 0, 20), "sd"),
                prior(student_t(3, 0, 20), "sigma")
              ) #prior
    ) #mod
    mod.sum = describe_posterior(mod,
                                 ci_method="hdi", test="pd") %>% as.data.frame()
    
    # Calculate Ann_Fec slope for each treatment:
    post <- posterior_samples(mod) 
    Jay_Slope    = post$b_Ann_Fec + post$'b_TreatmentJay:Ann_Fec'
    Raven_Slope    = post$b_Ann_Fec + post$'b_TreatmentRaven:Ann_Fec'
    Woodcock_Slope    = post$b_Ann_Fec + post$'b_TreatmentWoodcock:Ann_Fec'
    slope.sum = describe_posterior(data.frame("JaySlope" = Jay_Slope,
                                              "RavenSlope"=Raven_Slope,
                                              "WoodcockSlope"=Woodcock_Slope),
                                   ci_method="hdi", test="pd") %>% as.data.frame()
    
    # Calculate Phylogenetic Signal:
    hyp <- "sd_Latin__Intercept^2 / (sd_Latin__Intercept^2 + sigma^2) = 0"
    hyp <- hypothesis(mod, hyp, class = NULL)
    
    physig = data.frame("Parameter"=c("Lambda", "LambdaError"), "Median" = c(hyp$hypothesis$Estimate , hyp$hypothesis$Est.Error))
    output.i = bind_rows(mod.sum, slope.sum, physig)
    rownames(output.i) = output.i$Parameter
    mod.coefs[i,,] <- as.matrix(output.i[,-1], dimnames=dimnames(output.i))
    
    if(i%%20==0){save(mod.coefs, file="mod.coefs.Rdata")}
    
  }, error=function(e){
    cat("ERROR :",conditionMessage(e), "\n")
    errors <<- c(errors, i)})
} #i
# load("mod.coefs.Rdata")

# Coefficients:
describe_posterior(as.data.frame(mod.coefs[,5:9,1]), ci_method="hdi") # point estimate
describe_posterior(as.data.frame(mod.coefs[,5:9,5]), ci_method="hdi", rope_range=c(0.95, 1)) # pd

# Slopes
describe_posterior(as.data.frame(mod.coefs[,c(5,10:12),1]), ci_method="hdi") # point estimate

# Phyologenetic Signal
describe_posterior(as.data.frame(mod.coefs[,13:14,1]), ci_method="hdi") # upperCI



